@@ -1564,7 +1564,7 @@ xfce_backdrop_generate_canvas(XfceBackdrop *backdrop)
     if(backdrop->priv->color_style == XFCE_BACKDROP_COLOR_SOLID)
         final_image = create_solid(&backdrop->priv->color1, w, h);
     else if(backdrop->priv->color_style == XFCE_BACKDROP_COLOR_TRANSPARENT) {
-        GdkRGBA c = { 1.0f, 1.0f, 1.0f, 1.0f };
+        GdkRGBA c = { 1.0f, 1.0f, 1.0f, 0.0f };
         final_image = create_solid(&c, w, h);
     } else {
         final_image = create_gradient(&backdrop->priv->color1,
@@ -1599,6 +1599,11 @@ xfce_backdrop_image_data_release(XfceBackdropImageData *image_data)
 
     if(image_data->loader)
         g_object_unref(image_data->loader);
+
+    if(image_data->backdrop) {
+        g_object_unref(image_data->backdrop);
+        image_data->backdrop = NULL;
+    }
 }
 
 /**
@@ -1671,6 +1676,7 @@ xfce_backdrop_generate_async(XfceBackdrop *backdrop)
     backdrop->priv->image_data = image_data;
 
     image_data->backdrop = backdrop;
+    g_object_ref(backdrop);
     image_data->loader = gdk_pixbuf_loader_new();
     image_data->cancellable = g_cancellable_new();
     image_data->image_buffer = g_new0(guchar, XFCE_BACKDROP_BUFFER_SIZE);
@@ -1826,7 +1832,7 @@ xfce_backdrop_loader_closed_cb(GdkPixbufLoader *loader,
 
     /* if we don't need to do any scaling, don't do any interpolation.  this
      * fixes a problem where hyper/bilinear filtering causes blurriness in
-     * some images.  http://bugzilla.xfce.org/show_bug.cgi?id=2939 */
+     * some images.  https://bugzilla.xfce.org/show_bug.cgi?id=2939 */
     if(XFCE_BACKDROP_IMAGE_TILED == istyle
        || XFCE_BACKDROP_IMAGE_CENTERED == istyle)
     {
